/*------------------------------------------------------------------------------------------
//  Creation Date:  11/8/22
//  Author:		Greg Smith (gks)
//  Name:		ImvuMenu.ms
//  Description:  This script adds and/or rebuilds the IMVU menu on the main menu bar
//  Limitations:
//  Revisions:
------------------------------------------------------------------------------------------*/
format "Imvu Menu script loading\n"

(
	MENU_NAME = "IMVU"
	MENU_SEPERATOR = "seperator"

	-- Items are #(<string>macroScriptName <string>macroScriptCategory)
	MENU_ITEMS = #(
		--MENU_SEPERATOR,
		#("StudioToolkit", MENU_NAME)
	)

	------------------------------------------------------------------------------------------
	--Function:		MainMenuBuilderLoadMacroScripts
	--Desciption:		Loads all the macros before the menu script to insure they are available
	--Parameters:	none
	------------------------------------------------------------------------------------------
	fn MainMenuBuilderLoadMacroScripts = (
		macroFilesList = getFiles ((getDir #userMacros) + "/imvu/*.mcr") recurse:true
	 
		for file in macroFilesList do (
			format "ImvuMenu Loading: %" file
			fileIn file
		)
	)

	------------------------------------------------------------------------------------------
	--Function:		MainMenuBuilderAddMenu
	--Desciption:		Adds the custom menu to the Main Menu bar
	--Parameters:	<string> menuName <array> menuItems
	------------------------------------------------------------------------------------------
	fn MainMenuBuilderAddMenu menuName menuItems = (
		MainMenuBuilderLoadMacroScripts()

		local mainMenuBar = menuMan.getMainMenuBar()

		-- Rebuild the menu if necessary
		local theMenu = menuMan.findMenu menuName

		if (theMenu != undefined) then (
			while theMenu.numItems() > 0 do (
				theMenu.removeItemByPosition 1
			)
		)
		else (
			theMenu = menuMan.createMenu menuName
		)

		-- Add/re-add the menu in case it was manually removed by the user. :(
		local menuFound = false
		local numMainMenuItems = mainMenuBar.numItems()
		-- Per Maxscript documentation This is zero based index, but the Main Menu doesn't like 0
		for idx = 1 to numMainMenuItems do (
			if (mainMenuBar.getItem idx).getTitle() == menuName then menuFound = true
		)
		if not menuFound then (
			local newMenuItem = menuMan.createSubMenuItem menuName theMenu
			mainMenuBar.addItem newMenuItem -1
		)		
		
		-- Populate custom menu
		for item in menuItems do (
			local itemToAdd
			if item == MENU_SEPERATOR then (
				itemToAdd = menuMan.createSeparatorItem()
			)
			else (
				itemToAdd = menuMan.createActionItem item[1] item[2]
			)
			theMenu.addItem itemToAdd -1
		)

		-- Update the Main Menu bar
		menuMan.updateMenuBar()
	)

	MainMenuBuilderAddMenu MENU_NAME MENU_ITEMS
)